#  [[ name ]]

## Instructions

This project was built using Clay (https://github.com/lucuma/clay).

a) Run the development server with

```
clay run
```

b) Generate a static version of the site

```
clay build
```
